#ifndef BOARD_H
#define BOARD_H

#include <klistview.h>
#include <qstringlist.h>

class Board : public KListView
{
	Q_OBJECT
	public:
		Board(QWidget *parent = NULL, const char *name = NULL);
		~Board();
		void init(int type);
		void init2(QString type);
		void deleteTracks();
		void clear();
		void save(QString filename);
		void load(QString filename);
		QStringList list();
		QString type();

	public slots:
		void slotNewTrack(QStringList list);

	private:
		int m_changed;
		QString m_type;
		QListViewItem *m_replace;
};

#endif

